<template>
  <a-card
    title="预防性保养方案"
    :bordered='false'
  >
    <div class='table-page-search-wrapper'>
      <a-form
        layout='inline'
        @keyup.enter.native='searchQuery'
      >
        <a-row :gutter='24'>
          <a-col
            :xl='6'
            :lg='7'
            :md='8'
            :sm='24'
          >
            <a-form-item label='保养方案编码'>
              <a-input
                placeholder='请输入保养方案编码'
                v-model='queryParam.num'
              ></a-input>
            </a-form-item>
          </a-col>
          <!-- <a-col
            :xl='6'
            :lg='7'
            :md='8'
            :sm='24'
          >
            <a-form-item label='设备名称'>
              <a-input
                placeholder='请输入设备名称'
                v-model='queryParam.name'
              ></a-input>
            </a-form-item>
          </a-col> -->
          <a-col
            :xl='6'
            :lg='7'
            :md='8'
            :sm='24'
          >
            <span
              style='float: left;overflow: hidden;'
              class='table-page-search-submitButtons'
            >
              <a-button
                type='primary'
                @click='searchQuery'
                icon='search'
              >查询</a-button>
              <a-button
                type='primary'
                @click='searchReset'
                icon='reload'
                style='margin-left: 8px'
              >重置</a-button>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>

    <div class='table-operator'>
      <a-button
        @click='handleAdd'
        type='primary'
        icon='plus'
        v-has="'specialtyMaintenancePlan:add'"
      >新增</a-button>
    </div>

    <!-- table区域-begin -->
    <div>
      <div
        class='ant-alert ant-alert-info'
        style='margin-bottom: 16px;'
      >
        <i class='anticon anticon-info-circle ant-alert-icon'></i> 已选择 <a style='font-weight: 600'>{{ selectedRowKeys.length }}</a>项
        <a
          style='margin-left: 24px'
          @click='onClearSelected'
        >清空</a>
      </div>

      <a-table
        ref='table'
        size='middle'
        bordered
        rowKey='id'
        :scroll="{ x: 'calc(1400px + 50%)', y: 900 }"
        :columns='columns'
        :dataSource='dataSource'
        :pagination='ipagination'
        :loading='loading'
        :rowSelection='{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}'
        :customRow='clickThenSelect'
        @change='handleTableChange'
      >
        <span
          slot="status"
          slot-scope="text,record"
        >
          <a-badge
            v-if="record.status==1"
            status="success"
          />
          <span
            v-if="record.status==1"
            class="success"
          >启用</span>
          <a-badge
            v-if="record.status==0"
            status="error"
          />
          <span
            v-if="record.status==0"
            class="error"
          >禁用</span>
        </span>

        <span
          slot='action'
          slot-scope='text, record'
        >
          <a
            v-has="'specialtyMaintenancePlan:edit'"
            @click='handleEdit(record)'
          >编辑</a>

          <a-divider type='vertical' />
          <a-dropdown>
            <a class='ant-dropdown-link'>更多 <a-icon type='down' /></a>
            <a-menu slot='overlay'>
              <a-menu-item>
                <a-popconfirm
                  title='确定删除吗?'
                  @confirm='() => handleDelete(record.id)'
                >
                  <a v-has="'specialtyMaintenancePlan:delete'">删除</a>
                </a-popconfirm>
              </a-menu-item>
              <a-menu-item v-if="record.status == 0">
                <a-popconfirm
                  title="确定启用吗?"
                  @confirm="() => handleActive(record.id)"
                >
                  <a v-has="'specialtyMaintenancePlan:active'">启用</a>
                </a-popconfirm>
              </a-menu-item>
              <a-menu-item v-if="record.status == 1">
                <a-popconfirm
                  title="确定禁用吗?"
                  @confirm="() => handleActive(record.id)"
                >
                  <a v-has="'specialtyMaintenancePlan:active'">停用</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>

      </a-table>
      <a-tabs
        type="card"
        defaultActiveKey="1"
      >
        <a-tab-pane
          tab='保养明细'
          key="1"
        >
          <div
            class="table-operator"
            style="margin:-16px"
          >
            <specialty-maintenance-plan-detail :specialtyMaintenancePlanId='specialtyMaintenancePlanId' />
          </div>
        </a-tab-pane>

        <a-tab-pane
          tab='保养路线图'
          key="2"
        >
          <div
            class="table-operator"
            style="margin:-16px"
          >
            <photo-preview :specialtyMaintenancePlanId='specialtyMaintenancePlanId' />
          </div>
        </a-tab-pane>

      </a-tabs>
    </div>

    <specialty-Maintenance-plan-modal
      ref='modalForm'
      @ok='modalFormOk'
    ></specialty-maintenance-plan-modal>
  </a-card>
</template>

<script>

import { JeecgListMixin } from '@/mixins/JeecgListMixin'

import { getAction, requestPut } from '@/api/manage'
import SpecialtyMaintenancePlanDetail from './modules/specialtyMaintenancePlan/SpecialtyMaintenancePlanDetail'
import SpecialtyMaintenancePlanModal from './modules/specialtyMaintenancePlan/SpecialtyMaintenancePlanModal'
import PhotoPreview from './modules/specialtyMaintenancePlan/PhotoPreview'
import '@/assets/less/TableExpand.less'

export default {
  name: 'SpecialtyMaintenancePlanList',
  mixins: [JeecgListMixin],
  components: {
    SpecialtyMaintenancePlanDetail,
    SpecialtyMaintenancePlanModal,
    PhotoPreview
  },
  data() {
    return {
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function (t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '保养方案编码',
          align: 'center',
          dataIndex: 'num',
        },
        {
          title: '使用部门',
          align: 'center',
          dataIndex: 'departName',
        },
        {
          title: '保养类型',
          align: 'center',
          dataIndex: 'maintenanceTypeName',
        },
        {
          title: '维保方式',
          align: 'center',
          dataIndex: 'maintenanceModeName',
        },
        {
          title: '保养周期',
          align: 'center',
          dataIndex: 'maintenanceCycleName',
        },
        {
          title: '派工方式',
          align: 'center',
          dataIndex: 'assignModeName',
        },

        {
          title: '责任班组',
          align: 'center',
          dataIndex: 'teamName',
        },
        {
          title: '状态',
          align: 'center',
          dataIndex: 'status',
          scopedSlots: { customRender: 'status' },
        },
        {
          title: '创建人',
          align: 'center',
          dataIndex: 'createBy',
        },
        {
          title: '创建日期',
          align: 'center',
          dataIndex: 'createTime',
        },
        {
          title: '更新人',
          align: 'center',
          dataIndex: 'updateBy',
        },
        {
          title: '更新日期',
          align: 'center',
          dataIndex: 'updateTime',
        },
        {
          title: '备注',
          align: 'center',
          dataIndex: 'remark',
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          fixed: 'right',
          scopedSlots: { customRender: 'action' },
          width: 200,
        }
      ],
      url: {
        list: '/eam/specialtyMaintenancePlan/getSpecialtyMaintenancePlanList',
        delete: '/eam/specialtyMaintenancePlan/delete',
        deleteBatch: '/eam/specialtyMaintenancePlan/deleteBatch',
        active: '/eam/specialtyMaintenancePlan/active',
      },
      /* 分页参数 */
      ipagination: {
        current: 1,
        pageSize: 5,
        pageSizeOptions: ['5', '10', '50'],
        showTotal: (total, range) => {
          return range[0] + '-' + range[1] + ' 共' + total + '条'
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0
      },
      specialtyMaintenancePlanId: '-1'
    }
  },
  methods: {
    clickThenSelect(record) {
      return {
        on: {
          click: () => {
            this.onSelectChange(record.id.split(','), [record])
          }
        }
      }
    },
    onClearSelected() {
      this.selectedRowKeys = []
      this.selectionRows = []
      this.specialtyMaintenancePlanId = '-1'
    },
    onSelectChange(selectedRowKeys, selectionRows) {
      if (selectedRowKeys.length == 1) {
        this.specialtyMaintenancePlanId = selectionRows[0]['id']
      } else {
        this.specialtyMaintenancePlanId = '-1'
      }
      this.selectedRowKeys = selectedRowKeys
      this.selectionRows = selectionRows
    },
    loadData(arg) {
      if (!this.url.list) {
        this.$message.error('请设置url.list属性!')
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1
      }
      this.onClearSelected()
      var params = this.getQueryParams()//查询条件
      this.loading = true
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          this.dataSource = res.result.records
          this.ipagination.total = res.result.total
        }
        if (res.code === 510) {
          this.$message.warning(res.message)
        }
        this.loading = false
      })
    },
    searchReset() {
      this.specialtyMaintenancePlanId = '-1'
      this.queryParam = {}
      this.loadData(1);
    },

    //启用停用用
    handleActive(id) {
      let that = this;
      requestPut(that.url.active, {}, { id: id }).then((res) => {
        if (res.success) {
          that.$message.success(res.message);
          that.loadData(1);
        } else {
          that.$message.warning(res.message);
        }
      });
    },
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
.table-operator .ant-btn {
  margin: 10px 8px 8px 10px;
}
.success {
  color: green;
}
.error {
  color: red;
}
</style>